@@ -13,6 +13,7 @@
 # limitations under the License.
 
 import argparse
+import contextlib
 import json
 import logging
 import os
@@ -20,6 +21,10 @@ import pwd
 import shutil
 import sys
 
+from kazoo import client as kz_client
+from kazoo import exceptions as kz_exceptions
+from six.moves.urllib import parse
+
 
 # TODO(rhallisey): add docstring.
 logging.basicConfig()
@@ -45,7 +50,11 @@ def validate_config(config):
 def validate_source(data):
     source = data.get('source')
 
-    exists = os.path.exists(source)
+    if is_zk_transport(source):
+        with zk_connection(source) as zk:
+            exists = zk_path_exists(zk, source)
+    else:
+        exists = os.path.exists(source)
 
     if not exists:
         if data.get('optional'):
@@ -58,6 +67,61 @@ def validate_source(data):
     return True
 
 
+def is_zk_transport(path):
+    return path.startswith('zk://') or \
+        os.environ.get("KOLLA_ZK_HOSTS") is not None
+
+
+@contextlib.contextmanager
+def zk_connection(url):
+    # support an environment and url
+    # if url, it should be like this:
+    # zk://<address>:<port>/<path>
+
+    zk_hosts = os.environ.get("KOLLA_ZK_HOSTS")
+    if zk_hosts is None:
+        components = parse.urlparse(url)
+        zk_hosts = components.netloc
+    zk = kz_client.KazooClient(hosts=zk_hosts)
+    zk.start()
+    try:
+        yield zk
+    finally:
+        zk.stop()
+
+
+def zk_path_exists(zk, path):
+    try:
+        components = parse.urlparse(path)
+        zk.get(components.path)
+        return True
+    except kz_exceptions.NoNodeError:
+        return False
+
+
+def zk_copy_tree(zk, src, dest):
+    """Recursively copy contents of url_source into dest."""
+    data, stat = zk.get(src)
+
+    if data:
+        dest_path = os.path.dirname(dest)
+        if not os.path.exists(dest_path):
+            LOG.info("Creating dest parent directory: %s", dest_path)
+            os.makedirs(dest_path)
+
+        LOG.info("Copying %s to %s", src, dest)
+        with open(dest, 'w') as df:
+            df.write(data.decode("utf-8"))
+
+    try:
+        children = zk.get_children(src)
+    except kz_exceptions.NoNodeError:
+        return
+    for child in children:
+        zk_copy_tree(zk, os.path.join(src, child),
+                     os.path.join(dest, child))
+
+
 def copy_files(data):
     dest = data.get('dest')
     source = data.get('source')
@@ -69,6 +133,11 @@ def copy_files(data):
         else:
             os.remove(dest)
 
+    if is_zk_transport(source):
+        with zk_connection(source) as zk:
+            components = parse.urlparse(source)
+            return zk_copy_tree(zk, components.path, dest)
+
     if os.path.isdir(source):
         source_path = source
         dest_path = dest
