@@ -76,8 +76,7 @@ class BuildTestCentosBinary(BuildTest, base.BaseTestCase):
     def setUp(self):
         super(BuildTestCentosBinary, self).setUp()
         self.build_args.extend(["--base", "centos",
-                                "--type", "binary",
-                                "--tag", "1.1.0"])
+                                "--type", "binary"])
 
 
 class BuildTestCentosSource(BuildTest, base.BaseTestCase):
@@ -90,8 +89,7 @@ class BuildTestCentosSource(BuildTest, base.BaseTestCase):
     def setUp(self):
         super(BuildTestCentosSource, self).setUp()
         self.build_args.extend(["--base", "centos",
-                                "--type", "source",
-                                "--tag", "1.1.0"])
+                                "--type", "source"])
 
 
 class BuildTestUbuntuBinary(BuildTest, base.BaseTestCase):
@@ -102,8 +100,7 @@ class BuildTestUbuntuBinary(BuildTest, base.BaseTestCase):
     def setUp(self):
         super(BuildTestUbuntuBinary, self).setUp()
         self.build_args.extend(["--base", "ubuntu",
-                                "--type", "binary",
-                                "--tag", "1.1.0"])
+                                "--type", "binary"])
 
 
 class BuildTestUbuntuSource(BuildTest, base.BaseTestCase):
@@ -112,8 +109,7 @@ class BuildTestUbuntuSource(BuildTest, base.BaseTestCase):
     def setUp(self):
         super(BuildTestUbuntuSource, self).setUp()
         self.build_args.extend(["--base", "ubuntu",
-                                "--type", "source",
-                                "--tag", "1.1.0"])
+                                "--type", "source"])
 
 
 class BuildTestOracleLinuxBinary(BuildTest, base.BaseTestCase):
@@ -126,8 +122,7 @@ class BuildTestOracleLinuxBinary(BuildTest, base.BaseTestCase):
     def setUp(self):
         super(BuildTestOracleLinuxBinary, self).setUp()
         self.build_args.extend(["--base", "oraclelinux",
-                                "--type", "binary",
-                                "--tag", "1.1.0"])
+                                "--type", "binary"])
 
 
 class BuildTestOracleLinuxSource(BuildTest, base.BaseTestCase):
@@ -136,8 +131,7 @@ class BuildTestOracleLinuxSource(BuildTest, base.BaseTestCase):
     def setUp(self):
         super(BuildTestOracleLinuxSource, self).setUp()
         self.build_args.extend(["--base", "oraclelinux",
-                                "--type", "source",
-                                "--tag", "1.1.0"])
+                                "--type", "source"])
 
 
 class DeployTestCentosBinary(BuildTestCentosBinary):
